@@ -38,7 +38,8 @@ use Carp;
 @ISA = qw(Exporter DBI::Shell::Std);
 @EXPORT = qw(shell);
 
-$VERSION = '11.96_01';
+our $VERSION = '11.96_02'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 sub new {
 	my $class = shift;
@@ -664,22 +665,36 @@ sub readline {
 sub run_command {
     my ($sh, $command, $output, @args) = @_;
     return unless $command;
-    local(*STDOUT) if $output;
-    local(*OUTPUT) if $output;
-    if ($output) {
-		if (open(OUTPUT, $output)) {
-			*STDOUT = *OUTPUT;
-		} else {
-			$sh->err("Couldn't open output '$output': $!");
-			$sh->run_command('current', undef, '');
-		}
+
+    my $code = "do_$command";
+    if ($sh->can("$code")) {
+        local(*STDOUT) if $output;
+        local(*OUTPUT) if $output;
+        if ($output) {
+            if (open(OUTPUT, $output)) {
+                *STDOUT = *OUTPUT;
+            } else {
+                $sh->err("Couldn't open output '$output': $!");
+                $sh->run_command('current', undef, '');
+            }
+        }
+
+       local $@;
+
+       eval {
+            $sh->$code(@args);
+        };
+        close OUTPUT if $output;
+        $sh->err("$command failed: $@") if $@;
+    }
+    else {
+        if ($command eq 'spool') {
+            $sh->err("The DBI::Shell:Spool plug in needs to be installed. See https://rt.cpan.org/Ticket/Display.html?id=24538#txn-813176")
+        }
+        else {
+            $sh->err("$command does not exist, does a plug-in need to be installed?")
+        }
     }
-    eval {
-		my $code = "do_$command";
-		$sh->$code(@args);
-    };
-    close OUTPUT if $output;
-    $sh->err("$command failed: $@") if $@;	
 return;
 }
 
